@@ -11,27 +11,26 @@
 #include <QObject>
 #include <QString>
 #include <QVector>
+#include <qqmlintegration.h>
 
 #include "models/entriesproxymodel.h"
 
 class Feed : public QObject
 {
     Q_OBJECT
+    QML_ELEMENT
+    QML_UNCREATABLE("")
 
     Q_PROPERTY(QString url READ url CONSTANT)
-    Q_PROPERTY(QString name READ name WRITE setName NOTIFY nameChanged)
-    Q_PROPERTY(QString image READ image WRITE setImage NOTIFY imageChanged)
+    Q_PROPERTY(QString name READ name NOTIFY nameChanged)
+    Q_PROPERTY(QString image READ image NOTIFY imageChanged)
     Q_PROPERTY(QString cachedImage READ cachedImage NOTIFY cachedImageChanged)
-    Q_PROPERTY(QString link READ link WRITE setLink NOTIFY linkChanged)
-    Q_PROPERTY(QString description READ description WRITE setDescription NOTIFY descriptionChanged)
+    Q_PROPERTY(QString link READ link NOTIFY linkChanged)
+    Q_PROPERTY(QString description READ description NOTIFY descriptionChanged)
     Q_PROPERTY(QString authors READ authors NOTIFY authorsChanged)
     Q_PROPERTY(bool refreshing READ refreshing WRITE setRefreshing NOTIFY refreshingChanged)
-    Q_PROPERTY(int deleteAfterCount READ deleteAfterCount WRITE setDeleteAfterCount NOTIFY deleteAfterCountChanged)
-    Q_PROPERTY(int deleteAfterType READ deleteAfterType WRITE setDeleteAfterType NOTIFY deleteAfterTypeChanged)
     Q_PROPERTY(QDateTime subscribed READ subscribed CONSTANT)
     Q_PROPERTY(QDateTime lastUpdated READ lastUpdated WRITE setLastUpdated NOTIFY lastUpdatedChanged)
-    Q_PROPERTY(bool notify READ notify WRITE setNotify NOTIFY notifyChanged)
-    Q_PROPERTY(QString dirname READ dirname WRITE setDirname NOTIFY dirnameChanged)
     Q_PROPERTY(int entryCount READ entryCount NOTIFY entryCountChanged)
     Q_PROPERTY(int unreadEntryCount READ unreadEntryCount WRITE setUnreadEntryCount NOTIFY unreadEntryCountChanged)
     Q_PROPERTY(int newEntryCount READ newEntryCount NOTIFY newEntryCountChanged)
@@ -100,7 +99,7 @@ Q_SIGNALS:
     void unreadEntryCountChanged();
     void newEntryCountChanged();
     void favoriteEntryCountChanged();
-    void errorIdChanged(int &errorId);
+    void errorIdChanged(int errorId);
     void errorStringChanged(const QString &errorString);
 
     void refreshingChanged(bool refreshing);
@@ -109,6 +108,8 @@ private:
     void updateUnreadEntryCountFromDB();
     void updateNewEntryCountFromDB();
     void updateFavoriteEntryCountFromDB();
+    void initFilterType(int value);
+    void initSortType(int value);
 
     QString m_url;
     QString m_name;
@@ -127,8 +128,6 @@ private:
     int m_unreadEntryCount = -1;
     int m_newEntryCount = -1;
     int m_favoriteEntryCount = -1;
-
-    EntriesProxyModel *m_entries;
-
     bool m_refreshing = false;
+    EntriesProxyModel *m_entries;
 };
